@@ -2,6 +2,8 @@
 # @Time    : 2023-11-13 17:45
 # @Author  : Kem
 # @Desc    :
+import warnings
+warnings.filterwarnings("ignore")
 import sys
 
 from loguru import logger
@@ -11,6 +13,7 @@ from bricks.lib.request import Request  # noqa F401
 from bricks.lib.response import Response  # noqa F401
 from bricks.state import *  # noqa F403
 
+
 logger.remove(0)
 logger.add(
     sys.stdout,
