@@ -57,7 +57,7 @@ class Task(Future):
     """
 
     def __init__(
-        self, func, args=None, kwargs=None, callback=None, worker: "Worker" = None
+            self, func, args=None, kwargs=None, callback=None, worker: "Worker" = None
     ):
         self.func = func
         self.args = args or []
@@ -86,13 +86,13 @@ class Worker(threading.Thread):
     """
 
     def __init__(
-        self,
-        dispatcher: "Dispatcher",
-        name: str,
-        timeout=None,
-        daemon=True,
-        trace=False,
-        **kwargs,
+            self,
+            dispatcher: "Dispatcher",
+            name: str,
+            timeout=None,
+            daemon=True,
+            trace=False,
+            **kwargs,
     ):
         self.dispatcher = dispatcher
         self._shutdown = threading.Event()
@@ -311,9 +311,7 @@ class Dispatcher:
 
         timeout != -1 and self._running_tasks.acquire(timeout=timeout)
         submit()
-        timeout != -1 and task.add_done_callback(
-            lambda x: self._running_tasks.release()
-        )
+        timeout != -1 and task.add_done_callback(lambda x: self._running_tasks.release())
 
         self.adjust_workers()
         return task
@@ -444,7 +442,13 @@ class Dispatcher:
             await self._shutdown.wait()
             self._set_env()
 
-        asyncio.run(main())
+        try:
+            loop = asyncio.get_running_loop()
+            future = asyncio.run_coroutine_threadsafe(main(), loop=loop)
+            future.result()
+        except RuntimeError:
+            asyncio.run(main())
+
 
     def stop(self):
         self.stop_worker(*self.workers.keys())
