@@ -21,7 +21,6 @@ class RegisteredEvents:
         self.permanent = defaultdict(functools.partial(defaultdict, list))
         # 一次性事件
         self.disposable = defaultdict(functools.partial(defaultdict, list))
-        self.lazy_loading = defaultdict(functools.partial(defaultdict, list))
 
         self.registered: Dict[str, List[Register]] = defaultdict(list)
 
@@ -94,11 +93,11 @@ class EventManager:
 
     @classmethod
     def trigger(
-        cls,
-        context: Context,
-        errors: Literal["raise", "ignore", "output"] = "raise",
-        annotations: dict = None,  # type: ignore
-        namespace: dict = None,  # type: ignore
+            cls,
+            context: Context,
+            errors: Literal["raise", "ignore", "output"] = "raise",
+            annotations: dict = None,  # type: ignore
+            namespace: dict = None,  # type: ignore
     ):
         """
         trigger events: interact with external functions
@@ -116,11 +115,11 @@ class EventManager:
 
     @classmethod
     def invoke(
-        cls,
-        context: Context,
-        errors: Literal["raise", "ignore", "output"] = "raise",
-        annotations: dict = None,  # type: ignore
-        namespace: dict = None,  # type: ignore
+            cls,
+            context: Context,
+            errors: Literal["raise", "ignore", "output"] = "raise",
+            annotations: dict = None,  # type: ignore
+            namespace: dict = None,  # type: ignore
     ):
         """
         invoke events: invoke all events
@@ -132,18 +131,18 @@ class EventManager:
         :return:
         """
         for _ in cls.trigger(
-            context, errors=errors, annotations=annotations, namespace=namespace
+                context, errors=errors, annotations=annotations, namespace=namespace
         ):
             pass
 
     @classmethod
     def next(
-        cls,
-        ctx: Flow,
-        form: str,
-        annotations: dict = None,  # type: ignore
-        namespace: dict = None,  # type: ignore
-        callback: Callable = None,  # type: ignore
+            cls,
+            ctx: Flow,
+            form: str,
+            annotations: dict = None,  # type: ignore
+            namespace: dict = None,  # type: ignore
+            callback: Callable = None,  # type: ignore
     ):
         def main(context: Flow):
             EventManager.invoke(context, annotations=annotations, namespace=namespace)
@@ -179,24 +178,24 @@ class EventManager:
                 for event in events:
                     match = event.match
                     if (
-                        (match is None)
-                        or (callable(match) and match(context))
-                        or (
+                            (match is None)
+                            or (callable(match) and match(context))
+                            or (
                             isinstance(match, str)
                             and eval(match, globals(), {"context": context})
-                        )
+                    )
                     ):
                         event.disposable and event.box.remove(event)  # type: ignore
                         yield event
 
     @classmethod
     def _call(
-        cls,
-        event: Task,
-        context: Context,
-        errors: Literal["raise", "ignore", "output"] = "raise",
-        annotations: dict = None,  # type: ignore
-        namespace: dict = None,  # type: ignore
+            cls,
+            event: Task,
+            context: Context,
+            errors: Literal["raise", "ignore", "output"] = "raise",
+            annotations: dict = None,  # type: ignore
+            namespace: dict = None,  # type: ignore
     ):
         try:
             annotations = annotations or {}
@@ -249,21 +248,22 @@ class EventManager:
 
 
 def on(
-    form: str,
-    index: int = None,  # type: ignore
-    disposable: Optional[bool] = False,
-    binding: Any = ...,  # type: ignore
+        form: str,
+        index: Optional[int] = None,
+        disposable: Optional[bool] = False,
+        args: Optional[list] = None,
+        kwargs: Optional[dict] = None,
+        match: Optional[Union[Callable, str]] = None,
 ):
     """
     使用装饰器的方式注册事件
     如果有 staticmethod 之类的装饰器, 则需要紧贴着你的函数
 
 
-    :param binding: 事件作用对象, 默认为自动判断
-        如果是类相关的方法(静态方法, 类方法, 实例方法), 则会作用于该类的实例
-        如果是普通函数(则会作用于全局)
-        如果传入了对象, 则仅作用于该对象
-
+    :param is_global: 是否为全局事件, 如果非对象方法 / 类方法, 需要标识为 True 才会起作用
+    :param match:
+    :param kwargs:
+    :param args:
     :param form: 事件类型, 可以传入 const 属性
     :param index: 事件排序, 默认会在最后注册执行, 按照代码顺序索引一次递增, 索引越大, 执行速度越靠后
     :param disposable: 是否为可弃用事件(仅运行一次)
@@ -271,22 +271,19 @@ def on(
     """
 
     def inner(func):
-        if binding is ...:
-            if "." in func.__qualname__:
-                key = f"{func.__module__}.{func.__qualname__.rsplit('.', 1)[0]}"
-                REGISTERED_EVENTS.lazy_loading[key][form].append(
-                    Task(func=func.__name__, index=index, disposable=disposable)
-                )
-            else:
-                EventManager.register(
-                    Context(form=form),
-                    Task(func=func, index=index, disposable=disposable),
-                )
+        e = Task(
+            func=func,
+            index=index,
+            disposable=disposable,
+            args=args,
+            kwargs=kwargs,
+            match=match,
+        )
+
+        if "." in func.__qualname__:
+            EventManager.register(Context(form=form, target=None), e)
         else:
-            EventManager.register(
-                Context(form=form, target=binding),
-                Task(func=func, index=index, disposable=disposable),
-            )
+            setattr(func, "__event__", (form, e))
 
         return func
 
