@@ -21,32 +21,29 @@ class MetaClass(type):
         instance = type.__call__(cls, *args, **kwargs)
 
         # 加载拦截器
-        for method in filter(lambda x: str(x).startswith("_when_"), dir(instance)):
+        for method in dir(instance):
             # 修改被拦截的方法
-            raw_method_name = method.replace("_when_", "")
-            raw_method = getattr(instance, raw_method_name, None)
-            if not raw_method:
-                continue
+            if method.startswith("_when_"):
+                raw_method_name = method.replace("_when_", "")
+                raw_method = getattr(instance, raw_method_name, None)
+                if not raw_method:
+                    continue
+
+                method_wrapper = getattr(instance, method)
+                raw_method and setattr(
+                    instance, raw_method_name, method_wrapper(raw_method)
+                )  # type: ignore
+            else:
+                func = getattr(instance, method, None)
+                if not func or not callable(func):
+                    continue
+
+                if hasattr(func, "__event__"):
+                    instance.use(*func.__event__)
 
-            method_wrapper = getattr(instance, method)
-            raw_method and setattr(
-                instance, raw_method_name, method_wrapper(raw_method)
-            ) # type: ignore
 
         else:
-            hasattr(instance, "install") and instance.install() # type: ignore
-            key = f"{cls.__module__}.{cls.__name__}"
-            for form, events in REGISTERED_EVENTS.lazy_loading[key].items():
-                for event in events:
-                    instance.use(
-                        form,
-                        Task(
-                            func=getattr(instance, event.func),
-                            match=event.match,
-                            index=event.index,
-                            disposable=event.disposable,
-                        ),
-                    )
+            hasattr(instance, "install") and instance.install()  # type: ignore
 
         return instance
 
@@ -99,12 +96,12 @@ class Chaos(metaclass=MetaClass):
             return None
 
     def launch(
-        self,
-        scheduler: dict,
-        task_name: str = "all",
-        args=None,
-        kwargs=None,
-        callback: Callable = None,
+            self,
+            scheduler: dict,
+            task_name: str = "all",
+            args=None,
+            kwargs=None,
+            callback: Callable = None,
     ):
         """
         同 run, 但是是提交给调度器运行的, 可以定时执行
@@ -121,7 +118,7 @@ class Chaos(metaclass=MetaClass):
             self.run(task_name=task_name, args=args, kwargs=kwargs)
             callback and pandora.invoke(
                 callback, namespace={"spider": self}, annotations={type(self): self}
-            ) # type: ignore
+            )  # type: ignore
 
         form: Union[Literal["cron", "date", "interval"], BaseTrigger] = scheduler.pop(
             "form"
@@ -139,7 +136,7 @@ class Chaos(metaclass=MetaClass):
 
             except (signals.Failure, signals.Success):
                 logger.debug(f"[{const.BEFORE_START}] 任务被中断")
-                return
+                return None
 
             except signals.Signal as e:
                 logger.warning(f"[{const.BEFORE_START}] 无法处理的信号类型: {e}")
@@ -149,7 +146,7 @@ class Chaos(metaclass=MetaClass):
             try:
                 self.before_close()
             except signals.Signal as e:
-                logger.warning(f"[{const.BEFORE_START}] 无法处理的信号类型: {e}")
+                logger.warning(f"[{const.BEFORE_CLOSE}] 无法处理的信号类型: {e}")
 
             return ret
 
@@ -201,17 +198,17 @@ class Pangu(Chaos):
             self.set(k, v, nx=True)
 
         self.dispatcher = dispatch.Dispatcher(
-            max_workers=self.get("concurrency", default=1), # type: ignore
+            max_workers=self.get("concurrency", default=1),  # type: ignore
             options=self.get("dispatcher.options", default={}),
         )
 
     @property
     def plugins(self) -> List[Register]:
-        return REGISTERED_EVENTS.registered[self] # type: ignore
+        return REGISTERED_EVENTS.registered[self]  # type: ignore
 
-    def on_consume(self, context: Flow): # type: ignore
+    def on_consume(self, context: Flow):  # type: ignore
         context.doing.appendleft(context)
-        context.next.root == self.on_consume and context.flow() # type: ignore
+        context.next.root == self.on_consume and context.flow()  # type: ignore
 
         while True:
             context: Flow = context.produce()
@@ -233,7 +230,7 @@ class Pangu(Chaos):
                             args=[product],
                             annotations={type(context): context},
                             namespace={"context": context},
-                        ) # type: ignore
+                        )  # type: ignore
 
                     # 中断信号
                     except signals.Break:
@@ -302,7 +299,7 @@ class Pangu(Chaos):
         :return:
         """
         context = self.make_context(form=form)
-        register = EventManager.register(context, *events) # type: ignore
+        register = EventManager.register(context, *events)  # type: ignore
         return register
 
     @overload
@@ -327,7 +324,7 @@ class Pangu(Chaos):
         kwargs.setdefault("flows", self.flows)
         kwargs.setdefault("target", self)
         context = clazz(**kwargs)
-        return context # type: ignore
+        return context  # type: ignore
 
     @property
     def flows(self):
@@ -352,5 +349,5 @@ class Pangu(Chaos):
         exception: Exception = exception.error
         stack = pandora.get_pretty_stack(exception)
         logger.error(
-            f"[{context.form}] {exception.__class__.__name__}({exception})" f"\n{stack}" # type: ignore
+            f"[{context.form}] {exception.__class__.__name__}({exception})" f"\n{stack}"  # type: ignore
         )
