@@ -15,7 +15,9 @@ __all__ = (
 )
 
 # 当前 机器 ID
-MACHINE_ID = hashlib.sha256(uuid.UUID(int=uuid.getnode()).hex[-12:].encode()).hexdigest()
+MACHINE_ID = hashlib.sha256(
+    uuid.UUID(int=uuid.getnode()).hex[-12:].encode()
+).hexdigest()
 
 # 全局变量
 G = variable.VariableG()
@@ -25,14 +27,14 @@ T = variable.VariableT()
 
 class const:  # noqa
     # 事件类型
-    ERROR_OCCURRED = 'ERROR_OCCURRED'
+    ERROR_OCCURRED = "ERROR_OCCURRED"
 
-    BEFORE_START = 'BEFORE_START'
-    BEFORE_WORKER_START = 'BEFORE_WORKER_START'
-    BEFORE_CLOSE = 'BEFORE_CLOSE'
-    BEFORE_WORKER_CLOSE = 'BEFORE_WORKER_CLOSE'
+    BEFORE_START = "BEFORE_START"
+    BEFORE_WORKER_START = "BEFORE_WORKER_START"
+    BEFORE_CLOSE = "BEFORE_CLOSE"
+    BEFORE_WORKER_CLOSE = "BEFORE_WORKER_CLOSE"
 
-    ON_CONSUME = 'ON_CONSUME'
+    ON_CONSUME = "ON_CONSUME"
 
     BEFORE_GET_SEEDS = "BEFORE_GET_SEEDS"
     ON_SEEDS = "ON_SEEDS"
@@ -48,8 +50,8 @@ class const:  # noqa
     ON_REQUEST = "ON_REQUEST"
     AFTER_REQUEST = "AFTER_REQUEST"
 
-    ON_PARSE = 'ON_PARSE'
-    ON_INIT = 'ON_INIT'
+    ON_PARSE = "ON_PARSE"
+    ON_INIT = "ON_INIT"
 
     BEFORE_PIPELINE = "BEFORE_PIPELINE"
     ON_PIPELINE = "ON_PIPELINE"
@@ -57,4 +59,4 @@ class const:  # noqa
 
     BEFORE_MAKE_REQUEST = "BEFORE_MAKE_REQUEST"
     ON_MAKE_REQUEST = "ON_MAKE_REQUEST"
-    AFTER_MAKE_REQUEST = "AFTER_MAKE_REQUEST"
\ No newline at end of file
+    AFTER_MAKE_REQUEST = "AFTER_MAKE_REQUEST"
